@@ -19,9 +19,11 @@ package grpc_test
 
 import (
 	"context"
+	"time"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	"github.com/onsi/gomega/gleak"
 	grpclib "google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/credentials/insecure"
@@ -33,21 +35,39 @@ import (
 	"github.com/apache/skywalking-banyandb/banyand/liaison/grpc"
 	"github.com/apache/skywalking-banyandb/banyand/metadata"
 	"github.com/apache/skywalking-banyandb/banyand/queue"
+	"github.com/apache/skywalking-banyandb/pkg/grpchelper"
 	"github.com/apache/skywalking-banyandb/pkg/test"
+	testflags "github.com/apache/skywalking-banyandb/pkg/test/flags"
+	"github.com/apache/skywalking-banyandb/pkg/test/helpers"
+	teststream "github.com/apache/skywalking-banyandb/pkg/test/stream"
 )
 
 var _ = Describe("Registry", func() {
 	var gracefulStop func()
 	var conn *grpclib.ClientConn
+	var goods []gleak.Goroutine
 	meta := &commonv1.Metadata{
 		Group: "default",
 	}
+
 	BeforeEach(func() {
+		goods = gleak.Goroutines()
 		gracefulStop = setupForRegistry()
+		addr := "localhost:17912"
+		Eventually(
+			helpers.HealthCheck(addr, 10*time.Second, 10*time.Second, grpclib.WithTransportCredentials(insecure.NewCredentials())),
+			testflags.EventuallyTimeout).Should(Succeed())
 		var err error
-		conn, err = grpclib.Dial("localhost:17912", grpclib.WithTransportCredentials(insecure.NewCredentials()))
+		conn, err = grpchelper.Conn(addr, 10*time.Second, grpclib.WithTransportCredentials(insecure.NewCredentials()))
 		Expect(err).NotTo(HaveOccurred())
 	})
+
+	AfterEach(func() {
+		_ = conn.Close()
+		gracefulStop()
+		Eventually(gleak.Goroutines).ShouldNot(gleak.HaveLeaked(goods))
+	})
+
 	It("manages the stream", func() {
 		client := databasev1.NewStreamRegistryServiceClient(conn)
 		Expect(client).NotTo(BeNil())
@@ -68,6 +88,12 @@ var _ = Describe("Registry", func() {
 		})
 		errStatus, _ := status.FromError(err)
 		Expect(errStatus.Code()).To(Equal(codes.NotFound))
+		existResp, err := client.Exist(context.TODO(), &databasev1.StreamRegistryServiceExistRequest{
+			Metadata: meta,
+		})
+		Expect(err).ShouldNot(HaveOccurred())
+		Expect(existResp.HasGroup).To(BeTrue())
+		Expect(existResp.HasStream).To(BeFalse())
 		By("Creating a new stream")
 		_, err = client.Create(context.TODO(), &databasev1.StreamRegistryServiceCreateRequest{Stream: getResp.GetStream()})
 		Expect(err).ShouldNot(HaveOccurred())
@@ -77,6 +103,12 @@ var _ = Describe("Registry", func() {
 		})
 		Expect(err).ShouldNot(HaveOccurred())
 		Expect(getResp).NotTo(BeNil())
+		existResp, err = client.Exist(context.TODO(), &databasev1.StreamRegistryServiceExistRequest{
+			Metadata: meta,
+		})
+		Expect(err).ShouldNot(HaveOccurred())
+		Expect(existResp.HasGroup).To(BeTrue())
+		Expect(existResp.HasStream).To(BeTrue())
 	})
 	It("manages the index-rule-binding", func() {
 		client := databasev1.NewIndexRuleBindingRegistryServiceClient(conn)
@@ -138,10 +170,6 @@ var _ = Describe("Registry", func() {
 		Expect(err).ShouldNot(HaveOccurred())
 		Expect(getResp).NotTo(BeNil())
 	})
-	AfterEach(func() {
-		_ = conn.Close()
-		gracefulStop()
-	})
 })
 
 func setupForRegistry() func() {
@@ -164,7 +192,7 @@ func setupForRegistry() func() {
 	Expect(err).NotTo(HaveOccurred())
 	flags = append(flags, "--metadata-root-path="+metaPath, "--etcd-listen-client-url="+listenClientURL,
 		"--etcd-listen-peer-url="+listenPeerURL)
-	deferFunc := test.SetUpModules(
+	deferFunc := test.SetupModules(
 		flags,
 		repo,
 		pipeline,
@@ -172,8 +200,23 @@ func setupForRegistry() func() {
 		preloadStreamSvc,
 		tcp,
 	)
+	Eventually(
+		helpers.HealthCheck("localhost:17912", 10*time.Second, 10*time.Second, grpclib.WithTransportCredentials(insecure.NewCredentials())),
+		testflags.EventuallyTimeout).Should(Succeed())
 	return func() {
 		deferFunc()
 		metaDeferFunc()
 	}
 }
+
+type preloadStreamService struct {
+	metaSvc metadata.Service
+}
+
+func (p *preloadStreamService) Name() string {
+	return "preload-stream"
+}
+
+func (p *preloadStreamService) PreRun() error {
+	return teststream.PreloadSchema(p.metaSvc.SchemaRegistry())
+}
