@@ -30,16 +30,20 @@ import (
 	"github.com/apache/skywalking-banyandb/banyand/metadata"
 	"github.com/apache/skywalking-banyandb/banyand/metadata/schema"
 	"github.com/apache/skywalking-banyandb/banyand/queue"
+	"github.com/apache/skywalking-banyandb/banyand/tsdb"
+	"github.com/apache/skywalking-banyandb/pkg/bus"
 	"github.com/apache/skywalking-banyandb/pkg/logger"
 	"github.com/apache/skywalking-banyandb/pkg/run"
 	resourceSchema "github.com/apache/skywalking-banyandb/pkg/schema"
 )
 
 var (
-	ErrEmptyRootPath   = errors.New("root path is empty")
+	errEmptyRootPath = errors.New("root path is empty")
+	// ErrMeasureNotExist denotes a measure doesn't exist in the metadata repo.
 	ErrMeasureNotExist = errors.New("measure doesn't exist")
 )
 
+// Service allows inspecting the measure data points.
 type Service interface {
 	run.PreRunner
 	run.Config
@@ -51,14 +55,14 @@ var _ Service = (*service)(nil)
 
 type service struct {
 	schemaRepo    schemaRepo
-	writeListener *writeCallback
-	l             *logger.Logger
+	writeListener bus.MessageListener
 	metadata      metadata.Repo
-	root          string
 	pipeline      queue.Queue
 	repo          discovery.ServiceRepo
-	// stop channel for the service
-	stopCh chan struct{}
+	l             *logger.Logger
+	stopCh        chan struct{}
+	root          string
+	dbOpts        tsdb.DatabaseOpts
 }
 
 func (s *service) Measure(metadata *commonv1.Metadata) (Measure, error) {
@@ -68,6 +72,7 @@ func (s *service) Measure(metadata *commonv1.Metadata) (Measure, error) {
 	}
 	return sm, nil
 }
+
 func (s *service) LoadGroup(name string) (resourceSchema.Group, bool) {
 	return s.schemaRepo.LoadGroup(name)
 }
@@ -75,12 +80,15 @@ func (s *service) LoadGroup(name string) (resourceSchema.Group, bool) {
 func (s *service) FlagSet() *run.FlagSet {
 	flagS := run.NewFlagSet("storage")
 	flagS.StringVar(&s.root, "measure-root-path", "/tmp", "the root path of database")
+	flagS.Int64Var(&s.dbOpts.BlockMemSize, "measure-block-mem-size", 16<<20, "block memory size")
+	flagS.Int64Var(&s.dbOpts.SeriesMemSize, "measure-seriesmeta-mem-size", 1<<20, "series metadata memory size")
+	flagS.Int64Var(&s.dbOpts.BlockInvertedIndex.BatchWaitSec, "measure-idx-batch-wait-sec", 1, "index batch wait in second")
 	return flagS
 }
 
 func (s *service) Validate() error {
 	if s.root == "" {
-		return ErrEmptyRootPath
+		return errEmptyRootPath
 	}
 	return nil
 }
@@ -97,33 +105,33 @@ func (s *service) PreRun() error {
 	if err != nil {
 		return err
 	}
-	s.schemaRepo = newSchemaRepo(path.Join(s.root, s.Name()), s.metadata, s.repo, s.l)
+	s.schemaRepo = newSchemaRepo(path.Join(s.root, s.Name()), s.metadata, s.repo, s.dbOpts, s.l)
 	for _, g := range groups {
 		if g.Catalog != commonv1.Catalog_CATALOG_MEASURE {
 			continue
 		}
-		gp, err := s.schemaRepo.StoreGroup(g.Metadata)
-		if err != nil {
-			return err
+		gp, innerErr := s.schemaRepo.StoreGroup(g.Metadata)
+		if innerErr != nil {
+			return innerErr
 		}
 		ctx, cancel = context.WithTimeout(context.Background(), 5*time.Second)
-		schemas, err := s.metadata.MeasureRegistry().ListMeasure(ctx, schema.ListOpt{Group: gp.GetSchema().GetMetadata().Name})
+		allMeasureSchemas, innerErr := s.metadata.MeasureRegistry().
+			ListMeasure(ctx, schema.ListOpt{Group: gp.GetSchema().GetMetadata().GetName()})
 		cancel()
-		if err != nil {
-			return err
+		if innerErr != nil {
+			return innerErr
 		}
-		for _, sa := range schemas {
-			if _, innerErr := gp.StoreResource(sa); innerErr != nil {
+		for _, measureSchema := range allMeasureSchemas {
+			if _, innerErr := gp.StoreResource(measureSchema); innerErr != nil {
 				return innerErr
 			}
 		}
 	}
 
 	s.writeListener = setUpWriteCallback(s.l, &s.schemaRepo)
-
-	errWrite := s.pipeline.Subscribe(data.TopicMeasureWrite, s.writeListener)
-	if errWrite != nil {
-		return errWrite
+	err = s.pipeline.Subscribe(data.TopicMeasureWrite, s.writeListener)
+	if err != nil {
+		return err
 	}
 	return nil
 }
@@ -133,10 +141,41 @@ func (s *service) Serve() run.StopNotify {
 	// run a serial watcher
 	go s.schemaRepo.Watcher()
 
-	s.metadata.MeasureRegistry().RegisterHandler(schema.KindGroup|schema.KindMeasure|schema.KindIndexRuleBinding|schema.KindIndexRule,
-		&s.schemaRepo)
+	s.metadata.MeasureRegistry().
+		RegisterHandler(schema.KindGroup|schema.KindMeasure|schema.KindIndexRuleBinding|schema.KindIndexRule|schema.KindTopNAggregation,
+			&s.schemaRepo)
+
+	// start TopN manager after registering handlers
+	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+	groups, err := s.metadata.GroupRegistry().ListGroup(ctx)
+	cancel()
+
+	if err != nil {
+		s.l.Err(err).Msg("fail to list groups")
+		return s.stopCh
+	}
+
+	for _, g := range groups {
+		if g.Catalog != commonv1.Catalog_CATALOG_MEASURE {
+			continue
+		}
+		ctx, cancel = context.WithTimeout(context.Background(), 5*time.Second)
+		allMeasureSchemas, listErr := s.metadata.MeasureRegistry().
+			ListMeasure(ctx, schema.ListOpt{Group: g.GetMetadata().GetName()})
+		cancel()
+		if listErr != nil {
+			s.l.Err(listErr).Str("group", g.GetMetadata().GetName()).Msg("fail to list measures in the group")
+			continue
+		}
+		for _, measureSchema := range allMeasureSchemas {
+			if res, ok := s.schemaRepo.LoadResource(measureSchema.GetMetadata()); ok {
+				if startErr := res.(*measure).startSteamingManager(s.pipeline, s.metadata); startErr != nil {
+					s.l.Err(startErr).Str("measure", measureSchema.GetMetadata().GetName()).Msg("fail to start streaming manager")
+				}
+			}
+		}
+	}
 
-	s.stopCh = make(chan struct{})
 	return s.stopCh
 }
 
@@ -147,11 +186,12 @@ func (s *service) GracefulStop() {
 	}
 }
 
-// NewService returns a new service
+// NewService returns a new service.
 func NewService(_ context.Context, metadata metadata.Repo, repo discovery.ServiceRepo, pipeline queue.Queue) (Service, error) {
 	return &service{
 		metadata: metadata,
 		repo:     repo,
 		pipeline: pipeline,
+		stopCh:   make(chan struct{}),
 	}, nil
 }
