@@ -15,19 +15,37 @@
 // specific language governing permissions and limitations
 // under the License.
 
+// Package queue implements the data transmission queue.
 package queue
 
 import (
 	"github.com/apache/skywalking-banyandb/banyand/discovery"
 	"github.com/apache/skywalking-banyandb/pkg/bus"
+	"github.com/apache/skywalking-banyandb/pkg/run"
 )
 
-var _ bus.Publisher = (*local)(nil)
-var _ bus.Subscriber = (*local)(nil)
+var (
+	_ bus.Publisher  = (*local)(nil)
+	_ bus.Subscriber = (*local)(nil)
+)
 
 type local struct {
-	local *bus.Bus
-	repo  discovery.ServiceRepo
+	local  *bus.Bus
+	repo   discovery.ServiceRepo
+	stopCh chan struct{}
+}
+
+// GracefulStop implements Queue.
+func (l *local) GracefulStop() {
+	l.local.Close()
+	if l.stopCh != nil {
+		close(l.stopCh)
+	}
+}
+
+// Serve implements Queue.
+func (l *local) Serve() run.StopNotify {
+	return l.stopCh
 }
 
 func (l *local) Subscribe(topic bus.Topic, listener bus.MessageListener) error {
