@@ -30,8 +30,8 @@ import (
 	"github.com/apache/skywalking-banyandb/banyand/metadata"
 	"github.com/apache/skywalking-banyandb/banyand/metadata/schema"
 	"github.com/apache/skywalking-banyandb/banyand/tsdb"
-	"github.com/apache/skywalking-banyandb/pkg/encoding"
 	"github.com/apache/skywalking-banyandb/pkg/logger"
+	pb_v1 "github.com/apache/skywalking-banyandb/pkg/pb/v1/tsdb"
 	resourceSchema "github.com/apache/skywalking-banyandb/pkg/schema"
 )
 
@@ -41,7 +41,9 @@ type schemaRepo struct {
 	metadata metadata.Repo
 }
 
-func newSchemaRepo(path string, metadata metadata.Repo, repo discovery.ServiceRepo, l *logger.Logger) schemaRepo {
+func newSchemaRepo(path string, metadata metadata.Repo, repo discovery.ServiceRepo,
+	dbOpts tsdb.DatabaseOpts, l *logger.Logger,
+) schemaRepo {
 	return schemaRepo{
 		l:        l,
 		metadata: metadata,
@@ -49,7 +51,7 @@ func newSchemaRepo(path string, metadata metadata.Repo, repo discovery.ServiceRe
 			metadata,
 			repo,
 			l,
-			newSupplier(path, metadata, l),
+			newSupplier(path, metadata, dbOpts, l),
 			event.StreamTopicShardEvent,
 			event.StreamTopicEntityEvent,
 		),
@@ -169,14 +171,16 @@ func (sr *schemaRepo) loadStream(metadata *commonv1.Metadata) (*stream, bool) {
 var _ resourceSchema.ResourceSupplier = (*supplier)(nil)
 
 type supplier struct {
-	path     string
 	metadata metadata.Repo
 	l        *logger.Logger
+	path     string
+	dbOpts   tsdb.DatabaseOpts
 }
 
-func newSupplier(path string, metadata metadata.Repo, l *logger.Logger) *supplier {
+func newSupplier(path string, metadata metadata.Repo, dbOpts tsdb.DatabaseOpts, l *logger.Logger) *supplier {
 	return &supplier{
 		path:     path,
+		dbOpts:   dbOpts,
 		metadata: metadata,
 		l:        l,
 	}
@@ -187,26 +191,38 @@ func (s *supplier) OpenResource(shardNum uint32, db tsdb.Supplier, spec resource
 	return openStream(shardNum, db, streamSpec{
 		schema:     streamSchema,
 		indexRules: spec.IndexRules,
-	}, s.l)
+	}, s.l), nil
 }
-func (s *supplier) ResourceSchema(repo metadata.Repo, md *commonv1.Metadata) (resourceSchema.ResourceSchema, error) {
+
+func (s *supplier) ResourceSchema(md *commonv1.Metadata) (resourceSchema.ResourceSchema, error) {
 	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
 	defer cancel()
 	return s.metadata.StreamRegistry().GetStream(ctx, md)
 }
 
 func (s *supplier) OpenDB(groupSchema *commonv1.Group) (tsdb.Database, error) {
+	name := groupSchema.Metadata.Name
+	opts := s.dbOpts
+	opts.ShardNum = groupSchema.ResourceOpts.ShardNum
+	opts.Location = path.Join(s.path, groupSchema.Metadata.Name)
+	opts.CompressionMethod = tsdb.CompressionMethod{
+		Type:             tsdb.CompressionTypeZSTD,
+		ChunkSizeInBytes: chunkSize,
+	}
+	var err error
+	if opts.BlockInterval, err = pb_v1.ToIntervalRule(groupSchema.ResourceOpts.BlockInterval); err != nil {
+		return nil, err
+	}
+	if opts.SegmentInterval, err = pb_v1.ToIntervalRule(groupSchema.ResourceOpts.SegmentInterval); err != nil {
+		return nil, err
+	}
+	if opts.TTL, err = pb_v1.ToIntervalRule(groupSchema.ResourceOpts.Ttl); err != nil {
+		return nil, err
+	}
 	return tsdb.OpenDatabase(
 		context.WithValue(context.Background(), common.PositionKey, common.Position{
 			Module:   "stream",
-			Database: groupSchema.Metadata.Name,
+			Database: name,
 		}),
-		tsdb.DatabaseOpts{
-			Location: path.Join(s.path, groupSchema.Metadata.Name),
-			ShardNum: groupSchema.ResourceOpts.ShardNum,
-			EncodingMethod: tsdb.EncodingMethod{
-				EncoderPool: encoding.NewPlainEncoderPool(chunkSize),
-				DecoderPool: encoding.NewPlainDecoderPool(chunkSize),
-			},
-		})
+		opts)
 }
