@@ -15,6 +15,8 @@
 // specific language governing permissions and limitations
 // under the License.
 
+// Package stream implements a time-series-based storage which is consists of a sequence of element.
+// Each element drops in a arbitrary interval. They are immutable, can not be updated or overwritten.
 package stream
 
 import (
@@ -30,30 +32,32 @@ import (
 	"github.com/apache/skywalking-banyandb/pkg/schema"
 )
 
-// a chunk is 1MB
+// a chunk is 1MB.
 const chunkSize = 1 << 20
 
 var _ schema.Resource = (*stream)(nil)
 
 type stream struct {
-	name     string
-	group    string
-	shardNum uint32
-	l        *logger.Logger
-	// schema is the reference to the spec of the stream
-	schema *databasev1.Stream
-	// maxObservedModRevision is the max observed revision of index rules in the spec
-	maxObservedModRevision int64
 	db                     tsdb.Supplier
+	l                      *logger.Logger
+	schema                 *databasev1.Stream
+	indexWriter            *index.Writer
+	name                   string
+	group                  string
 	entityLocator          partition.EntityLocator
 	indexRules             []*databasev1.IndexRule
-	indexWriter            *index.Writer
+	maxObservedModRevision int64
+	shardNum               uint32
 }
 
 func (s *stream) GetMetadata() *commonv1.Metadata {
 	return s.schema.Metadata
 }
 
+func (s *stream) GetSchema() *databasev1.Stream {
+	return s.schema
+}
+
 func (s *stream) GetIndexRules() []*databasev1.IndexRule {
 	return s.indexRules
 }
@@ -67,7 +71,7 @@ func (s *stream) EntityLocator() partition.EntityLocator {
 }
 
 func (s *stream) Close() error {
-	return s.indexWriter.Close()
+	return nil
 }
 
 func (s *stream) parseSpec() {
@@ -81,7 +85,7 @@ type streamSpec struct {
 	indexRules []*databasev1.IndexRule
 }
 
-func openStream(shardNum uint32, db tsdb.Supplier, spec streamSpec, l *logger.Logger) (*stream, error) {
+func openStream(shardNum uint32, db tsdb.Supplier, spec streamSpec, l *logger.Logger) *stream {
 	sm := &stream{
 		shardNum:   shardNum,
 		schema:     spec.schema,
@@ -93,10 +97,11 @@ func openStream(shardNum uint32, db tsdb.Supplier, spec streamSpec, l *logger.Lo
 
 	sm.db = db
 	sm.indexWriter = index.NewWriter(ctx, index.WriterOptions{
-		DB:         db,
-		ShardNum:   shardNum,
-		Families:   spec.schema.TagFamilies,
-		IndexRules: spec.indexRules,
+		DB:                db,
+		ShardNum:          shardNum,
+		Families:          spec.schema.TagFamilies,
+		IndexRules:        spec.indexRules,
+		EnableGlobalIndex: true,
 	})
-	return sm, nil
+	return sm
 }
