@@ -6,7 +6,7 @@
 // not use this file except in compliance with the License.
 // You may obtain a copy of the License at
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
+//	http://www.apache.org/licenses/LICENSE-2.0
 //
 // Unless required by applicable law or agreed to in writing,
 // software distributed under the License is distributed on an
@@ -14,7 +14,6 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
-//
 package bucket_test
 
 import (
@@ -24,6 +23,7 @@ import (
 	. "github.com/onsi/gomega"
 
 	"github.com/apache/skywalking-banyandb/pkg/logger"
+	"github.com/apache/skywalking-banyandb/pkg/test/flags"
 )
 
 func TestBucket(t *testing.T) {
@@ -31,7 +31,7 @@ func TestBucket(t *testing.T) {
 	BeforeSuite(func() {
 		Expect(logger.Init(logger.Logging{
 			Env:   "dev",
-			Level: "warn",
+			Level: flags.LogLevel,
 		})).Should(Succeed())
 	})
 	RunSpecs(t, "Bucket Suite")
